﻿(function () {
    "use strict";
    var Application=WinJS.Application;
    var Activation=Windows.ApplicationModel.Activation;
    var ActivationKind=Activation.ActivationKind;
    var ApplicationExecutionState=Activation.ApplicationExecutionState;
    var IndexedDB=window.msIndexedDB;
    var IDBTransaction=window.IDBTransaction;
    WinJS.strictProcessing();

    //変数
    var db=null;

    //アプリ起動時と再開時に呼ばれる
    Application.onactivated=function(eventObject) {
        if (eventObject.detail.kind===ActivationKind.launch) {
            if (eventObject.detail.previousExecutionState!==
                ApplicationExecutionState.terminated) {
                Application.onlaunched(eventObject);
            }
            WinJS.UI.processAll();
        }
    };

    //アプリ起動時に呼ばれる
    Application.onlaunched=function(eventObject) {
        //データベースとの接続(1)
        var request=IndexedDB.open("myDatabase6",1);
        request.onupgradeneeded=function(evt) {
            db=request.result;
            try {
                //オブジェクトストレージ生成(2)
                var objectStore=db.createObjectStore("myObjectStore",{keyPath:"name"});

                //オブジェクトストアのインデックスの生成(3)
                objectStore.createIndex("myIndex","type",{unique:true});
            } catch (e) {
                //オブジェクトストレージ生成済
            }
        };
        request.onsuccess=function() {
            db=request.result;
        };
        request.onerror=function(event) {
            showDialog("接続エラー");
        };

        //イベントリスナーの指定
        $("writeButton").addEventListener("click",writeButton_onClick);
        $("readButton0").addEventListener("click",readButton0_onClick);
        $("readButton1").addEventListener("click",readButton1_onClick);
    };

    //アプリ開始
    Application.start();

    //書き込みボタン押下時に呼ばれる
    function writeButton_onClick() {
        if (!db) return;

        //オブジェクトストアへのデータの書き込み(4)
        var text=$("textarea").value;
        var objectStore=db.transaction(db.objectStoreNames,
            "readwrite").objectStore("myObjectStore");
        objectStore.put({name:"test", type:"text", value:text});
    }

    //キー検索による読み込みボタンクリック時に呼ばれる
    function readButton0_onClick() {
        if (!db) return;

        //オブジェクトストアからのキー検索によるデータ読み込み(5)
        var objectStore=db.transaction(db.objectStoreNames
            ).objectStore("myObjectStore");
        var re=objectStore.get("test");
        re.onsuccess=function(data){
            var record=re.result;
            if (!record) return;
            $("textarea").value=record.value;
        };
    }

    //インデックス検索による読み込みボタンクリック時に呼ばれる
    function readButton1_onClick() {
        if (!db) return;

        //オブジェクトストアからのインデックス検索によるデータ読み込み(6)
        var objectStore=db.transaction(db.objectStoreNames
            ).objectStore("myObjectStore");
        var re=objectStore.index("myIndex").openCursor("text");
        re.onsuccess=function(data) {
            var cursor=re.result;
            if (cursor) {
                var record=cursor.value;
                if (!record) return;
                $("textarea").value=record.value;
            }
        };
    }

    //ダイアログの表示
    function showDialog(text) {
        var md=new Windows.UI.Popups.MessageDialog(text);
        var cmd=new Windows.UI.Popups.UICommand();
        cmd.label="OK";
        md.commands.append(cmd);
        md.showAsync();
    }

    //要素の取得
    function $(id) {
        return document.getElementById(id);
    }
})();