﻿(function () {
    "use strict";
    var Application=WinJS.Application;
    var Activation=Windows.ApplicationModel.Activation;
    var ActivationKind=Activation.ActivationKind;
    var ApplicationExecutionState=Activation.ApplicationExecutionState;
    var Sockets=Windows.Networking.Sockets;
    var DataWriter=Windows.Storage.Streams.DataWriter;
    var MessageWebSocket=Sockets.MessageWebSocket;
    var SocketMessageType=Sockets.SocketMessageType;
    var Uri=Windows.Foundation.Uri;
    WinJS.strictProcessing();

    //変数
    var webSocket;
    var dataWriter;

    //アプリ起動時と再開時に呼ばれる
    Application.onactivated=function(eventObject) {
        if (eventObject.detail.kind===ActivationKind.launch) {
            if (eventObject.detail.previousExecutionState!==
                ApplicationExecutionState.terminated) {
                Application.onlaunched(eventObject);
            }
            WinJS.UI.processAll();
        }
    };

    //アプリ起動時に呼ばれる
    Application.onlaunched=function(eventObject) {
        //チャットサーバのURLの指定(1)
        var serverAddress=new Uri("ws://localhost:8888/chat/");

        //WebSocketの生成(2)
        webSocket=new MessageWebSocket();
        webSocket.control.messageType=SocketMessageType.utf8;

        //WebSocketのイベント処理(3)
        webSocket.onmessagereceived=onMessageReceived;
        webSocket.onclosed=onClosed;

        //WebSocketの接続(4)
        webSocket.connectAsync(serverAddress).then(
            function(data) {
                dataWriter=new DataWriter(webSocket.outputStream);
            }, 
            function(error) {
                $("log").innerHTML=$("log").innerHTML+"<br>"+error;
            }
        );
        
        //イベントリスナーの指定
        $("sendButton").addEventListener("click",sendButton_onClick);
    };

    //アプリ開始
    Application.start();

    //送信ボタン押下時に呼ばれる
    function sendButton_onClick() {
        if (dataWriter==null) return;

        //サーバへのデータ送信(5)
        var str=$("textarea").value;
        dataWriter.writeString(str);
        dataWriter.storeAsync();
        $("textarea").value="";
    }

    //メッセージ受信時の処理(6)
    function onMessageReceived(args) {
        var dataReader=args.getDataReader();
        var str=dataReader.readString(dataReader.unconsumedBufferLength);
        $("log").innerHTML=$("log").innerHTML+"<br>"+str;
    }

    //ソケット切断時に呼ばれる
    function onClosed(args) {
        webSocket=null;
        dataWriter=null;
    }

    //要素の取得
    function $(id) {
        return document.getElementById(id);
    }
})();