﻿(function () {
    "use strict";
    var Application=WinJS.Application;
    var Activation=Windows.ApplicationModel.Activation;
    var ActivationKind=Activation.ActivationKind;
    var ApplicationExecutionState=Activation.ApplicationExecutionState;
    var MessageDialog=Windows.UI.Popups.MessageDialog;
    var BackgroundTaskBuilder=Windows.ApplicationModel.Background.BackgroundTaskBuilder;
    var BackgroundTaskRegistration=Windows.ApplicationModel.Background.BackgroundTaskRegistration;
    var SystemTrigger=Windows.ApplicationModel.Background.SystemTrigger;
    var SystemTriggerType=Windows.ApplicationModel.Background.SystemTriggerType;
    var MaintenanceTrigger=Windows.ApplicationModel.Background.MaintenanceTrigger;
    var TimeTrigger=Windows.ApplicationModel.Background.TimeTrigger;
    WinJS.strictProcessing();

    //アプリ起動時と再開時に呼ばれる
    Application.onactivated=function(args) {
        if (args.detail.kind===ActivationKind.launch) {
            if (args.detail.previousExecutionState!==
                ApplicationExecutionState.terminated) {
                Application.onlaunched(args);
            }
            onDraw();
            args.setPromise(WinJS.UI.processAll());
        }
    };

    //アプリ起動時に呼ばれる
    Application.onlaunched=function(args) {
        //イベントリスナーの指定
        $("button0").addEventListener("click",button0_onClick);
        $("button1").addEventListener("click",button1_onClick);
        $("button2").addEventListener("click",button2_onClick);
        $("button3").addEventListener("click",button3_onClick);
    };

    //アプリ開始
    Application.start();

    //システムによるバックグラウンドタスク登録押下時に呼ばれる
    function button0_onClick() {
        unregisterBackgroundTask("MySystemBackgroundTask");
        registerSystemBackgroundTask();
        onDraw();
    }

    //メンテナンスによるバックグラウンドタスク登録押下時に呼ばれる
    function button1_onClick() {
        unregisterBackgroundTask("MyMaintenanceBackgroundTask");
        registerMaintenanceBackgroundTask();
        onDraw();
    }

    //タイマーによるバックグラウンドタスク登録押下時に呼ばれる
    function button2_onClick() {
        unregisterBackgroundTask("MyTimeBackgroundTask");
        registerTimeBackgroundTask();
        onDraw();
    }

    //バックグラウンドタスク登録解除押下時に呼ばれる
    function button3_onClick() {
        unregisterBackgroundTask("MySystemBackgroundTask");
        unregisterBackgroundTask("MyMaintenanceBackgroundTask");
        unregisterBackgroundTask("MyTimeBackgroundTask");
        onDraw();
    }
    
    //システムによるバックグラウンドタスク登録(1)
    function registerSystemBackgroundTask() {
        var builder=new BackgroundTaskBuilder();
        var trigger=new SystemTrigger(SystemTriggerType.timeZoneChange,false);
        builder.name="MySystemBackgroundTask";
        builder.taskEntryPoint="js\\backgroundtask.js";
        builder.setTrigger(trigger);
        builder.register();
    }

    //メンテナンスによるバックグラウンドタスク登録(2)
    function registerMaintenanceBackgroundTask() {
        var builder=new BackgroundTaskBuilder();
        var trigger=new MaintenanceTrigger(15,false);
        builder.name="MyMaintenanceBackgroundTask";
        builder.taskEntryPoint="js\\backgroundtask.js";
        builder.setTrigger(trigger);
        builder.register();
    }

    //タイマーによるバックグラウンドタスク登録(3)
    function registerTimeBackgroundTask() {
        var builder=new BackgroundTaskBuilder();
        var trigger=new TimeTrigger(15,false);
        builder.name="MyTimeBackgroundTask";
        builder.taskEntryPoint="js\\backgroundtask.js";
        builder.setTrigger(trigger);
        builder.register();
    }

    //バックグラウンドタスクの登録解除
    function unregisterBackgroundTask(taskName) {
        var iter=BackgroundTaskRegistration.allTasks.first();
        var hascur=iter.hasCurrent;
        while (hascur) {
            var cur=iter.current.value;
            if (cur.name===taskName) {
                cur.unregister(true);
            }
            hascur=iter.moveNext();
        }   
    }

    //描画時に呼ばれる
    function onDraw() {
        Debug.writeln("flag>"+BackgroundTaskRegistration.allTasks.first());
        var str="";
        var iter=BackgroundTaskRegistration.allTasks.first();
        var hascur=iter.hasCurrent;
        while (hascur) {
            var cur=iter.current.value;
            str+=cur.name+"<br>";
            hascur=iter.moveNext();
        }   
        $("output").innerHTML=str;
    }

    //要素の取得
    function $(id) {
        return document.getElementById(id);
    }
})();