﻿(function () {
    "use strict";
    var Application=WinJS.Application;
    var Activation=Windows.ApplicationModel.Activation;
    var ActivationKind=Activation.ActivationKind;
    var ApplicationExecutionState=Activation.ApplicationExecutionState;
    var Geolocator=Windows.Devices.Geolocation.Geolocator;
    var PositionStatus=Windows.Devices.Geolocation.PositionStatus;
    WinJS.strictProcessing();

    //ジオロケーター
    var geolocator;  //ジオロケーター
    var latitude =0; //緯度
    var longitude=0; //経度
    var accuracy =0; //精度
    var status   =-1;//状態

    //アプリ起動時と再開時に呼ばれる
    Application.onactivated=function(args) {
        if (args.detail.kind===ActivationKind.launch) {
            if (args.detail.previousExecutionState!==
                ApplicationExecutionState.terminated) {
                Application.onlaunched(args);
            }

            //ジオロケーターの有効化
            enableGeolocator();
            args.setPromise(WinJS.UI.processAll());
        }
    };

    //アプリ起動時に呼ばれる
    Application.onlaunched=function(args) {
    }

    //アプリ一時停止時に呼ばれる
    Application.oncheckpoint=function(args) {
        //ジオロケーターの無効化
        disableGeolocator();
    }

    //アプリ開始
    Application.start();

    //ジオロケーターの有効化(1)
    function enableGeolocator() {
        geolocator=new Geolocator();
        geolocator.addEventListener("positionchanged",onPositionChanged);
        geolocator.addEventListener("statuschanged",onStatusChanged);
    }

    //ジオロケーターの無効化
    function disableGeolocator() {
        if (geolocator!=null) {
            geolocator.removeEventListener("positionchanged",onPositionChanged);
            geolocator.removeEventListener("statuschanged",onStatusChanged);
        }
    }

    //位置変更時に呼ばれる
    function onPositionChanged(e) {
        //位置情報の取得
        var coord=e.position.coordinate;
        latitude=coord.latitude;
        longitude=coord.longitude;
        accuracy=coord.accuracy;

        //描画
        onDraw();
    }
    
    //状態変更時に呼ばれる
    function onStatusChanged(e) {
        //状態の取得
        status=e.status;

        //描画
        onDraw();
    }

    //描画時に呼ばれる
    function onDraw() {
        var str="";

        //ジオロケーターの値
        if (geolocator!=null) {
            str+="緯度:"+latitude+"<br>"+
                "経度:"+longitude+"<br>"+
                "精度:"+accuracy+"<br>";
            if (status==PositionStatus.ready) {
                str+="状態:ready<br>";
            } else if (status==PositionStatus.initializing) {
                str+="状態:initializing<br>";
            } else if (status==PositionStatus.noData) {
                str+="状態:noData<br>";
            } else if (status==PositionStatus.disabled) {
                str+="状態:disabled<br>";
            } else if (status==PositionStatus.initialized) {
                str+="状態:initialized<br>";
            } else if (status==PositionStatus.available) {
                str+="状態:available<br>";
            }
        }

        //描画
        $("output").innerHTML=str;
    }

    //要素の取得
    function $(id) {
        return document.getElementById(id);
    }
})();