﻿(function () {
    "use strict";
    var Application=WinJS.Application;
    var Activation=Windows.ApplicationModel.Activation;
    var ActivationKind=Activation.ActivationKind;
    var ApplicationExecutionState=Activation.ApplicationExecutionState;
    var Accelerometer=Windows.Devices.Sensors.Accelerometer;
    var SimpleOrientationSensor=Windows.Devices.Sensors.SimpleOrientationSensor;
    var SimpleOrientation=Windows.Devices.Sensors.SimpleOrientation;
    WinJS.strictProcessing();

    //加速度センサー
    var accelerometer;  //加速度センサー
    var accelerationX=0;//X軸方向の加速度
    var accelerationY=0;//Y軸方向の加速度
    var accelerationZ=0;//Z軸方向の加速度

    //シンプル端末向きセンサー
    var orientationSensor;//シンプル端末向きセンサー
    var orientation=0;    //端末向き

    //アプリ起動時と再開時に呼ばれる
    Application.onactivated=function(args) {
        if (args.detail.kind===ActivationKind.launch) {
            if (args.detail.previousExecutionState!==
                ApplicationExecutionState.terminated) {
                Application.onlaunched(args);
            }
            //センサーの有効化
            enableSensor();
            args.setPromise(WinJS.UI.processAll());
        }
    };

    //アプリ起動時に呼ばれる
    Application.onlaunched=function(args) {
    }

    //アプリ一時停止時に呼ばれる
    Application.oncheckpoint=function(args) {
        //センサーの無効化
        disableSensor();
    }

    //アプリ開始
    Application.start();

    //センサーの有効化
    function enableSensor() {
        //加速度センサーの有効化(1)
        accelerometer=Accelerometer.getDefault();
        if (accelerometer!=null) {
            var minimumReportInterval=accelerometer.minimumReportInterval;
            var reportInterval=minimumReportInterval>16?minimumReportInterval:16;
            accelerometer.reportInterval=reportInterval;
            accelerometer.addEventListener("readingchanged",onAccelerometerChanged);
        }

        //シンプル端末向きセンサーの有効化(3)
        orientationSensor=SimpleOrientationSensor.getDefault();
        if (orientationSensor!=null) {
            var minimumReportInterval=orientationSensor.minimumReportInterval;
            var reportInterval=minimumReportInterval>16?minimumReportInterval:16;
            orientationSensor.reportInterval=reportInterval;
            orientationSensor.addEventListener("orientationchanged",onOrientationChanged);
        }
    }

    //センサーの無効化(5)
    function disableSensor() {
        //加速度センサーの無効化
        if (accelerometer!=null) {
            accelerometer.removeEventListener("readingchanged",onAccelerometerChanged);
        }

        //シンプル端末向きセンサーの無効化
        if (orientationSensor!=null) {
            orientationSensor.removeEventListener("orientationchanged",onOrientationChanged);
        }
    }

    //加速度センサーの値変更時に呼ばれる
    function onAccelerometerChanged(e) {
        //加速度センサーの値の取得(2)
        var reading=e.reading;
        accelerationX=reading.accelerationX;
        accelerationY=reading.accelerationY;
        accelerationZ=reading.accelerationZ;

        //描画
        onDraw();
    }

    //端末向きセンサーの値変更時に呼ばれる
    function onOrientationChanged(e) {
        //シンプル端末向きセンサーの値の取得(4)
        orientation=e.orientation;

        //描画
        onDraw();
    }

    //描画時に呼ばれる
    function onDraw() {
        var str="";

        //加速度センサーの値
        if (accelerometer!=null) {
            str+="加速度X:"+accelerationX.toFixed(2)+"<br>"+
                "加速度Y:"+accelerationY.toFixed(2)+"<br>"+
                "加速度Z:"+accelerationZ.toFixed(2)+"<br>";
        }

        //端末向きセンサーの値
        if (orientationSensor!=null) {
            if (orientation==SimpleOrientation.notRotated) {
                str+="端末向き:notRotated<br>";
            } else if (orientation==SimpleOrientation.rotated90DegreesCounterclockwise) {
                str+="端末向き:rotated90DegreesCounterclockwise<br>";
            } else if (orientation==SimpleOrientation.rotated180DegreesCounterclockwise) {
                str+="端末向き:rotated180DegreesCounterclockwise<br>";
            } else if (orientation==SimpleOrientation.rotated270DegreesCounterclockwise) {
                str+="端末向き:rotated270DegreesCounterclockwise<br>";
            } else if (orientation==SimpleOrientation.faceup) {
                str+="端末向き:faceup<br>";
            } else if (orientation==SimpleOrientation.facedown) {
                str+="端末向き:facedown<br>";
            }
        }

        //描画
        $("output").innerHTML=str;
    }

    //要素の取得
    function $(id) {
        return document.getElementById(id);
    }
})();